
robotpy-cscore
==============

This is documentation for the python bindings for `cscore <https://github.com/wpilibsuite/cscore>`_,
a high performance camera access and streaming library introduced by FIRST in
2017. It can be used to:

* Stream a USB/HTTP camera to SmartDashboard or the LabVIEW dashboard via HTTP
* Capture images from USB or HTTP camera, modify them using OpenCV/Numpy, and
  send them via HTTP to SmartDashboard, the LabVIEW dashboard, or a web browser.

.. include:: _sidebar.rst.inc

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
